package com.fastest.pass.home.presentation.ui.fragment

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material.Scaffold
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.ComposeView
import androidx.compose.ui.res.colorResource
import androidx.fragment.app.viewModels
import com.fastest.pass.app.BaseFragment
import com.fastest.pass.R
import com.fastest.pass.home.presentation.ui.components.ClickType
import com.fastest.pass.home.presentation.ui.components.HomeScreen
import com.fastest.pass.home.presentation.viewmodels.HomeViewModel
import com.fastest.pass.home.utils.HomeNavigation
import com.fastest.pass.home.utils.HomeRoute
import com.fastest.pass.ui.theme.FastestPassTheme
import dagger.hilt.android.AndroidEntryPoint
import javax.inject.Inject

@AndroidEntryPoint
class HomeFragment : BaseFragment() {

    val viewmodel: HomeViewModel by viewModels()

    @Inject
    lateinit var navigation: HomeNavigation

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        navigation.navigate(this)
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        return ComposeView(requireActivity()).apply {
            setContent {
                FastestPassTheme {
                    Scaffold(
                        modifier = Modifier.fillMaxSize()
                    ) { paddingValues ->
                        Box(
                            modifier = Modifier
                                .fillMaxSize()
                                .background(colorResource(id = R.color.home_background_color))
                                .padding(paddingValues.calculateBottomPadding())
                        ) {
                            HomeScreen { clickType ->
                                when (clickType) {
                                    ClickType.GOTO_ADD_NEW_ITEMS -> {
                                        viewmodel.navigateTo(HomeRoute.OpenAddNewItemsScreen)
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}